@@ -99,8 +99,8 @@ VERBS_MAP = {
     "mosaic_tags": "updated mosaic tags for",
     "update_default_panels": "updated default panels for",
     "update_clinical_filter_hpo": "updated clinical filter HPO status for",
-    "mme_add": "exported to MatchMaker patient",
-    "mme_remove": "removed from MatchMaker patient",
+    "mme_add": "exported to Matchmaker patient",
+    "mme_remove": "removed from Matchmaker patient",
     "filter_stash": "stored a filter for",
     "filter_audit": "marked case audited with filter",
     "update_sample": "updated sample data for",
