@@ -14,16 +14,16 @@ def test_index(mock_app):
     result = runner.invoke(cli, ["index"])
     # It should print confirm message
     assert (
-        "This will delete and rebuild all indexes(if not --update). Are you sure? [y/N]"
+        "This will delete and rebuild indexes(if not --update) for the given collections (or the whole database). Are you sure?"
         in result.output
     )
 
     # Provide confirm command to CLI (say yes)
-    result = runner.invoke(cli, ["index"], input="y")
+    result = runner.invoke(cli, ["index", "-c", "hgnc_gene"], input="y")
     assert result.exit_code == 0
     assert "INFO creating indexes" in result.output
 
     # Provide confirm command and update option
-    result = runner.invoke(cli, ["index", "--update"], input="y")
+    result = runner.invoke(cli, ["index", "--update", "-c", "hgnc_gene"], input="y")
     assert result.exit_code == 0
     assert "INFO All indexes in place" in result.output
