@@ -14,7 +14,7 @@ def test_update_case_no_args(mock_app):
     result = runner.invoke(cli, ["update", "case"])
 
     ## THEN it should return an error message
-    assert "Please specify which case to update" in result.output
+    assert "Please specify either a case ID or both case name and institute ID" in result.output
 
 
 def test_update_case_wrong_collaborator(mock_app, case_obj):
