@@ -5,6 +5,32 @@ import pytest
 from scout.utils import ensembl_rest_clients
 
 
+@pytest.fixture()
+def igv_public_track():
+    """Return a dictionary coresponding to a public IGV track"""
+    public_track = {
+        "name": "custom_public_bucket",
+        "access": "public",
+        "tracks": [
+            {
+                "name": "Test public track",
+                "type": "variant",
+                "format": "vcf",
+                "build": "37",
+                "url": "url/to/public/track",
+                "indexURL": "url/to/public/track.index",
+            }
+        ],
+    }
+    return public_track
+
+
+@pytest.fixture
+def igv_test_tracks(igv_public_track):
+    """Returns a list with test tracks for igv.js"""
+    return [igv_public_track]  # this will contain also a private track in the future
+
+
 @pytest.fixture
 def refseq_response():
     """Return the string that is a refseq response"""
